@@ -1,8 +1,6 @@
 from django.apps import AppConfig
-from django.conf import settings
 from django.template import engines
 
-from .util import get_dmp_instance, log, DMP_OPTIONS
 
 
 class Config(AppConfig):
@@ -20,4 +18,3 @@ class Config(AppConfig):
 
 
 
-
