@@ -5,6 +5,8 @@ from django.core.exceptions import ImproperlyConfigured
 import base64
 import os, os.path
 import collections
+import zlib
+
 
 # this is populated with the dictionary of options in engine.py when
 # Django initializes the template engine
@@ -103,4 +105,36 @@ def split_app(path):
     return None, path
 
 
+def crc32(filename):
+    '''
+    Calculates the CRC checksum for a file.
+    Using CRC32 because security isn't the issue and don't need perfect noncollisions.
+    We just need to know if a file has changed.
+
+    On my machine, crc32 was 20 times faster than any hashlib algorithm,
+    including blake and md5 algorithms.
+    '''
+    result = 0
+    with open(filename, 'rb') as fin:
+        while True:
+            chunk = fin.read(48)
+            if len(chunk) == 0:
+                break
+            result = zlib.crc32(chunk, result)
+    return result
+
+
 EMPTY = object()
+def getdefaultattr(obj, name, default=None, factory=EMPTY):
+    '''
+    Gets the given attribute from the object,
+    creating it with a default or by calling
+    a factory if needed.
+    '''
+    try:
+        return getattr(obj, name)
+    except AttributeError:
+        pass
+    val = factory() if factory is not EMPTY else None
+    setattr(obj, name, val)
+    return val
